## 0.2.0 (2023-07-09)
### feat
- [[`aab4af6`](https://gitlab.com/katalytic/katalytic/commit/aab4af641604f014ba42b099eab7d1c1da153046)] merge all plugins without 3rd-party dependencies into this package: data, files, maths, pkg
### fix
- [[`f06af0f`](https://gitlab.com/katalytic/katalytic/commit/f06af0f2c3399bb46b1db0d8eb30c94715d81a31)] add katalytic.py back
- [[`e73a745`](https://gitlab.com/katalytic/katalytic/commit/e73a745b5662154a5c03c44762beca9ab9627296)] merge katalytic-data
### docs
- [[`944e7a3`](https://gitlab.com/katalytic/katalytic/commit/944e7a331971653ec921d6d485e223eea31c8a08)] add CODE_OF_CONDUCT.md
- [[`d90a41e`](https://gitlab.com/katalytic/katalytic/commit/d90a41ed481fb8cbc46d7ff87e882fcb2a0e64f6)] **pyproject.toml:** update project URLs


## 0.1.1 (2023-04-14)
### Fix
* Release ([`4f4fef5`](https://github.com/katalytic/katalytic/commit/4f4fef569b4e6e4f87e34c4a1d1b3212ec6961cc))
* Release ([`82e12e6`](https://github.com/katalytic/katalytic/commit/82e12e6542c4da66679f748304520f6ee130b45f))
* Remove test_collection.py because it depends on the toml in folders outside the repo ([`b85b441`](https://github.com/katalytic/katalytic/commit/b85b4410b75db3ce5ce139f68fba13a993aad6f1))
* **pyproject.toml:** Add [tool.flit.module] section. flit requires it ([`08ad69e`](https://github.com/katalytic/katalytic/commit/08ad69e7825396e85294e6d9a8a5e16ecb95282b))
* Uncomment "flit build" ([`345c3f9`](https://github.com/katalytic/katalytic/commit/345c3f904d199728d57a6da94f8244dea22b5849))


